
#include "absthresholdaction.h"
#include "applybandpassaction.h"
#include "baselineselectionaction.h"
#include "calibratebandpassaction.h"
#include "changeresolutionaction.h"
#include "combineflagresultsaction.h"
#include "cutareaaction.h"
#include "eigenvalueverticalaction.h"
#include "foreachbaselineaction.h"
#include "foreachcomplexcomponentaction.h"
#include "foreachmsaction.h"
#include "foreachpolarisationaction.h"
#include "foreachsimulatedbaselineaction.h"
#include "frequencyconvolutionaction.h"
#include "frequencyselectionaction.h"
#include "fringestopaction.h"
#include "imageraction.h"
#include "iterationaction.h"
#include "highpassfilteraction.h"
#include "normalizevarianceaction.h"
#include "plotaction.h"
#include "quickcalibrateaction.h"
#include "resamplingaction.h"
#include "saveheatmapaction.h"
#include "setflaggingaction.h"
#include "setimageaction.h"
#include "slidingwindowfitaction.h"
#include "morphologicalflagaction.h"
#include "strategy.h"
#include "svdaction.h"
#include "sumthresholdaction.h"
#include "timeconvolutionaction.h"
#include "timeselectionaction.h"
#include "visualizeaction.h"
#include "writedataaction.h"
#include "writeflagsaction.h"

